==> haskell-ghcide-2.1.0.0-59-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-ghcide.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.1.0.0
visibility:           public
id:                   ghcide-2.1.0.0-7mveeBu1NdO3tDaPLTwSr0
key:                  ghcide-2.1.0.0-7mveeBu1NdO3tDaPLTwSr0
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  5d0f25ddfd1e1912eb3952bba6c74c3e
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Spans.AtPoint Development.IDE.Spans.Common
    Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.4.8/site-local/ghcide-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ghcide-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ghcide-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.1.0.0-7mveeBu1NdO3tDaPLTwSr0
depends:
    Diff-0.5-2Up5HNAxZSNmr3b9Y21Rq Glob-0.10.2-3QVYkf3SaJR6RNS9OX3HgD
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg
    aeson-pretty-0.8.10-FQa8xIJIIpZJMrtrbu8IN4 array-0.5.4.0
    async-2.2.5-DWviBtrYTc7K8qRxzPsJC base-4.17.2.1
    base16-bytestring-1.0.2.0-ASFphLrgXvi67bm2qxzorY binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-JVWVUVinOoKLKsx1rHKuw7
    co-log-core-0.3.2.5-4V3HmgoGkXErp4Ib9Tvbp containers-0.6.7
    cryptohash-sha1-0.11.101.0-24zEmBYT7AR5XuoQwLI2BZ
    data-default-0.7.1.2-7bG7braRZax6ZJaJ3dSesR deepseq-1.4.8.0
    dependent-map-0.4.0.0-A5BslNuifQi6hSLOxRhcNb
    dependent-sum-0.7.2.0-64NwSxh4hq3AnuRd8xoA0j directory-1.3.7.1
    dlist-1.0-E99MqJW5mmB4kr4PCgIESI
    enummapset-0.7.3.0-BWmMbrX8xp71Yvkb4cCUzM exceptions-0.10.5
    extra-1.7.16-KxrHBQWVwMp2M62XitBte8 filepath-1.4.2.2
    fingertree-0.1.6.2-HyFF8R8DbBb1f3TaBV8sAi
    focus-1.0.3.2-9UG6aWIJYQU1dpGJUMaXsH ghc-9.4.8 ghc-boot-9.4.8
    ghc-boot-th-9.4.8 ghc-check-0.5.0.8-KkqvoSEiE2hAxeVTrUDaje
    ghc-paths-0.1.0.12-8lmZj1VFo8V7iNy4rcXCyj
    ghc-trace-events-0.1.2.9-7ocQkvnjYWsA9rDcBsLuv7
    haddock-library-1.11.0-EwStvZmo4ci3GFlv5CMsYF
    hashable-1.4.4.0-HF0gObldLcB4LirfpxeD3R
    hie-bios-0.12.0-9MqyXfNlNQe4AP5ks5mD6C
    hie-compat-0.3.1.1-EX7c63LZz6m3PpO1VmTjuM
    hiedb-0.4.3.0-77h4cPeELCh59Sg9LsTnNF
    hls-graph-2.1.0.0-E0uwKa062XbErlHzLpQDMc
    hls-plugin-api-2.1.0.0-2mMBQBjk997A47exxFPkZd
    implicit-hie-0.1.4.0-4gORIw4Q5qr9jIMIe76RUm
    implicit-hie-cradle-0.5.0.1-LdhhSa8B4OJAs1oSEZzXGp
    lens-5.3.1-57CGCDOUfQCLkJSlnZcVUR
    list-t-1.0.5.7-Kce3kPVfPFH8fgauyBPiZn
    lsp-2.1.0.0-GxokUjVxBLy4j05JlhgdFg
    lsp-types-2.0.1.0-11kcCUIWM0n8rW3sZUJHGA mtl-2.2.2
    opentelemetry-0.8.0-G42Ux5z93NJFKMGTHzrBMD
    optparse-applicative-0.18.1.0-3qYZezrQAxc4lJKAil0WN1
    parallel-3.2.2.0-KJ5o3ImR3G8wdLWLqGjpy
    prettyprinter-1.7.1-18Jm3UFnGYW2Ifx2izjEAg
    prettyprinter-ansi-terminal-1.1.3-7xtieJh015GBqxFnpOTjap
    random-1.2.1.3-KpmZVmsijPULH6l5PrmXSD
    regex-tdfa-1.3.2.4-9ZyuPp8BFYO5HpZyySDZc8
    row-types-1.0.1.2-FQkLZYizLy6IrD2AIWrDwp
    safe-exceptions-0.1.7.4-JJtencRNvfPAVPHD6bpNCc
    sorted-list-0.2.3.1-1RE8jt0x7DqIclSCiBuL2r
    sqlite-simple-0.4.19.0-7u0AghWadLu8LxwMGeIVws stm-2.5.1.0
    stm-containers-1.2.1.1-86Il8Zl0y3y9pRWBbzkv1j
    syb-0.7.3-Lap6GPARkRXCVbqA2faY6P text-2.0.2
    text-rope-0.3-B63XxTtZ9rH6f5aGYdHxkH time-1.12.2
    transformers-0.5.6.2 unix-2.7.3
    unliftio-0.2.25.1-83PwQVOhURl3H5nxoMcX3o
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20-89DcpQLd7HI30AdGz5XyJk
    vector-0.13.2.0-AtXaKVcIvtCInBZOrzSe57

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghcide-2.1.0.0-94-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-ghcide.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.1.0.0
visibility:           public
id:                   ghcide-2.1.0.0-EGobQkKgR8zaeADYgxOC5
key:                  ghcide-2.1.0.0-EGobQkKgR8zaeADYgxOC5
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  9b734e08d3c5acd53cda2ec06d13b9a8
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Spans.AtPoint Development.IDE.Spans.Common
    Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.4.8/site-local/ghcide-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ghcide-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ghcide-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.1.0.0-EGobQkKgR8zaeADYgxOC5
depends:
    Diff-0.5-2tX1FyxWy6p7M2fvM0xekx Glob-0.10.2-KsmqzAMtUBqD2GDD9ejCew
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk
    aeson-pretty-0.8.10-7oLs7OTWYk9GnMVCodyIc4 array-0.5.4.0
    async-2.2.5-GGvJE1nOBFYGFw0FXsPFU0 base-4.17.2.1
    base16-bytestring-1.0.2.0-1Uz6oHjhPf9KewF5fWee2u binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-4psXWcL2Or6Ff92NkDcfKY
    co-log-core-0.3.2.5-1Xm391iqQA3JzPA3ZEW0rk containers-0.6.7
    cryptohash-sha1-0.11.101.0-ABJXCufxSvFHV6sCEE1AN3
    data-default-0.7.1.3-1SaGr9SWFYZ17MG1fTAOKi deepseq-1.4.8.0
    dependent-map-0.4.0.0-9FVcuUWCdBEKIaOnZNTwf6
    dependent-sum-0.7.2.0-IQOxEtOpDj9EMXMMNpnepJ directory-1.3.7.1
    dlist-1.0-DlYyWPxbaG7vpSilKIFCh
    enummapset-0.7.3.0-IsIkPK0KuYVFgMzAUWSNFS exceptions-0.10.5
    extra-1.7.16-CyTEZvSfBxsKCwY9ZtJE7E filepath-1.4.2.2
    fingertree-0.1.6.2-9t49hsSqDY3BaiXjhf8y3o
    focus-1.0.3.2-8hrsVfu9SCyGKwxAyYgRHl ghc-9.4.8 ghc-boot-9.4.8
    ghc-boot-th-9.4.8 ghc-check-0.5.0.8-KRdvMsnKJiSCGhiumEH3t5
    ghc-paths-0.1.0.12-8lmZj1VFo8V7iNy4rcXCyj
    ghc-trace-events-0.1.2.9-7ocQkvnjYWsA9rDcBsLuv7
    haddock-library-1.11.0-59D2fhKWwUI3gJ6E0Z8YsM
    hashable-1.4.7.0-KrA5CwhmktQ6Qu5a4JCqq7
    hie-bios-0.12.0-9XHeK8HLoeP7nIXSeWEUTe
    hie-compat-0.3.1.1-EX7c63LZz6m3PpO1VmTjuM
    hiedb-0.4.3.0-HW3gq1S374kGrDfXQW41UV
    hls-graph-2.1.0.0-7LnpvrkjhrNH9iznMLZXCG
    hls-plugin-api-2.1.0.0-EfBvd6pBF3is65S9wzuFu
    implicit-hie-0.1.4.0-1PjgBq5GgmFHElPc0sqYLl
    implicit-hie-cradle-0.5.0.1-5VYWUxWhcJ75pzT0fB628d
    lens-5.3.3-1zYcQilqoBK5EhYwkXjOnb
    list-t-1.0.5.7-GdSuNSaT7D1HbJEvfXY0bP
    lsp-2.1.0.0-4wEItkatDyfAFCzTPH6SAN
    lsp-types-2.0.1.0-EjYcMkrIVdu9wybjt2x400 mtl-2.2.2
    opentelemetry-0.8.0-1GnhCvPQQwZIOxPglvSHYP
    optparse-applicative-0.18.1.0-t4C6chS8YH5x9x9VuRkT0
    parallel-3.2.2.0-KJ5o3ImR3G8wdLWLqGjpy
    prettyprinter-1.7.1-IxfK3MMc5TsGC7SkX421m7
    prettyprinter-ansi-terminal-1.1.3-AVYpYA7i4fdJ805glBa68
    random-1.2.1.3-KY8hXIsRO0nEsZvihu4hBT
    regex-tdfa-1.3.2.5-71D7aDzS2d23Ft8PQEnlRo
    row-types-1.0.1.2-4x8U1r2LNA9AnBIlVe6fUq
    safe-exceptions-0.1.7.4-E2jhex6cl0w6t2rEagsyOt
    sorted-list-0.2.3.1-1EyuINttNxEHWSXCyB2xGD
    sqlite-simple-0.4.19.0-LE0uG2byo4o8ltMLMAEHAX stm-2.5.1.0
    stm-containers-1.2.1.1-JkQzghCiirYSX2KXoZcs5
    syb-0.7.3-C5AaeelSWDKGvBUWTjIxkt text-2.0.2
    text-rope-0.3-31JrMTK7qlyJ4XXJrO6vBR time-1.12.2
    transformers-0.5.6.2 unix-2.7.3
    unliftio-0.2.25.1-jUDvU4O8PS8SoQvWmG5yt
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20.1-JRJBW0Nl9iEJULI134IWXM
    vector-0.13.2.0-DhQEcquLn8PDmAHUsOvAGS

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
